@@ -1901,8 +1901,13 @@ class Module:
                 parameter_doc: str
                 for parameter_doc in self._add_init_parameter_docs:
                     parameter_doc = sob.utilities.string.indent(
-                        parameter_doc.lstrip(" -"), number_of_spaces=6
+                        parameter_doc.lstrip(" -"), number_of_spaces=6, start=0
                     )
+                    parameter_doc = (
+                        sob.utilities.string.split_long_docstring_lines(
+                            parameter_doc
+                        )
+                    ).lstrip()
                     parameter_documentation = (
                         f"{parameter_documentation}\n    - {parameter_doc}"
                     )
